==> haskell-ptr-0.16.8.7-97-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ptr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ptr
version:              0.16.8.7
visibility:           public
id:                   ptr-0.16.8.7-6DLOU2m0FyuvPXvVLrzZQ
key:                  ptr-0.16.8.7-6DLOU2m0FyuvPXvVLrzZQ
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/ptr
synopsis:             Experimental abstractions for operations on pointers
description:
    Collection of experimental abstractions over pointer operations.

category:             Ptr, Data
abi:                  19e9dd92c09c1e685d094cd8848241b5
exposed:              True
exposed-modules:
    Ptr.ByteString Ptr.IO Ptr.Parse Ptr.ParseUnbound Ptr.Peek Ptr.Poke
    Ptr.PokeAndPeek Ptr.Poking Ptr.Read Ptr.Receive

hidden-modules:
    Ptr.List Ptr.PokeIO Ptr.Prelude Ptr.Receive.Core
    Ptr.UncheckedShifting Ptr.Util.ByteString Ptr.Util.Word8Predicates

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ptr
hs-libraries:         HSptr-0.16.8.7-6DLOU2m0FyuvPXvVLrzZQ
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    profunctors-5.6.3-7SwpvPUR3WDDKDPlUxhog4
    strict-list-0.1.7.6-E6f5OqHUPYwHapSHNfAn4X text-2.0.2 time-1.12.2
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57

haddock-interfaces:   /usr/share/doc/haskell-ptr/html/ptr.haddock
haddock-html:         /usr/share/doc/haskell-ptr/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ptr-0.16.8.7-118-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ptr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ptr
version:              0.16.8.7
visibility:           public
id:                   ptr-0.16.8.7-Bb7pYhEdXIuH06foj3hAO9
key:                  ptr-0.16.8.7-Bb7pYhEdXIuH06foj3hAO9
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/ptr
synopsis:             Experimental abstractions for operations on pointers
description:
    Collection of experimental abstractions over pointer operations.

category:             Ptr, Data
abi:                  f96b78ac784c32195a8a4e3aa303682f
exposed:              True
exposed-modules:
    Ptr.ByteString Ptr.IO Ptr.Parse Ptr.ParseUnbound Ptr.Peek Ptr.Poke
    Ptr.PokeAndPeek Ptr.Poking Ptr.Read Ptr.Receive

hidden-modules:
    Ptr.List Ptr.PokeIO Ptr.Prelude Ptr.Receive.Core
    Ptr.UncheckedShifting Ptr.Util.ByteString Ptr.Util.Word8Predicates

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ptr
hs-libraries:         HSptr-0.16.8.7-Bb7pYhEdXIuH06foj3hAO9
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    profunctors-5.6.3-GJws21l5du15P9B6ShOpfs
    strict-list-0.1.7.6-Gp4P2fAFLd95io9mTvhaEq text-2.0.2 time-1.12.2
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:   /usr/share/doc/haskell-ptr/html/ptr.haddock
haddock-html:         /usr/share/doc/haskell-ptr/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
